@@ -9,18 +9,20 @@ generated_file_path = args[3]
 
 # Deployment files
 hash_mac = args[4].strip()
-hash_linux = args[5].strip()
+hash_mac_arm = args[5].strip()
+hash_linux = args[6].strip()
 
 print("Generating formula")
 print("     VERSION: %s" % version)
 print("     TEMPLATE PATH: %s" % template_file_path)
 print("     SAVING AT: %s" % generated_file_path)
 print("     MAC HASH: %s" % hash_mac)
+print("     MAC ARM HASH: %s" % hash_mac_arm)
 print("     LINUX HASH: %s" % hash_linux)
 
 with open(template_file_path, "r") as template_file:
     template = Template(template_file.read())
-    substitute = template.safe_substitute(version=version, hash_mac=hash_mac, hash_linux=hash_linux)
+    substitute = template.safe_substitute(version=version, hash_mac=hash_mac, hash_mac_arm=hash_mac_arm, hash_linux=hash_linux)
     print("\n================== Generated package file ==================\n")
     print(substitute)
     print("\n============================================================\n")
