@@ -3,7 +3,6 @@ use std::collections::BTreeMap;
 use async_trait::async_trait;
 use k8s_openapi::{api::core::v1::ConfigMap, chrono::Utc};
 use ratatui::{
-  backend::Backend,
   layout::{Constraint, Rect},
   widgets::{Cell, Row},
   Frame,
@@ -59,7 +58,7 @@ pub struct ConfigMapResource {}
 
 #[async_trait]
 impl AppResource for ConfigMapResource {
-  fn render<B: Backend>(block: ActiveBlock, f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
+  fn render(block: ActiveBlock, f: &mut Frame<'_>, app: &mut App, area: Rect) {
     draw_resource_tab!(
       CONFIG_MAPS_TITLE,
       block,
@@ -80,7 +79,7 @@ impl AppResource for ConfigMapResource {
   }
 }
 
-fn draw_block<B: Backend>(f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
+fn draw_block(f: &mut Frame<'_>, app: &mut App, area: Rect) {
   let title = get_resource_title(app, CONFIG_MAPS_TITLE, "", app.data.config_maps.items.len());
 
   draw_resource_block(
