@@ -1,7 +1,6 @@
 use async_trait::async_trait;
 use k8s_openapi::{api::batch::v1::CronJob, chrono::Utc};
 use ratatui::{
-  backend::Backend,
   layout::{Constraint, Rect},
   widgets::{Cell, Row},
   Frame,
@@ -76,7 +75,7 @@ pub struct CronJobResource {}
 
 #[async_trait]
 impl AppResource for CronJobResource {
-  fn render<B: Backend>(block: ActiveBlock, f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
+  fn render(block: ActiveBlock, f: &mut Frame<'_>, app: &mut App, area: Rect) {
     draw_resource_tab!(
       CRON_JOBS_TITLE,
       block,
@@ -97,7 +96,7 @@ impl AppResource for CronJobResource {
   }
 }
 
-fn draw_block<B: Backend>(f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
+fn draw_block(f: &mut Frame<'_>, app: &mut App, area: Rect) {
   let title = get_resource_title(app, CRON_JOBS_TITLE, "", app.data.cronjobs.items.len());
 
   draw_resource_block(
