@@ -1,7 +1,6 @@
 use async_trait::async_trait;
 use k8s_openapi::{api::apps::v1::Deployment, chrono::Utc};
 use ratatui::{
-  backend::Backend,
   layout::{Constraint, Rect},
   widgets::{Cell, Row},
   Frame,
@@ -74,7 +73,7 @@ pub struct DeploymentResource {}
 
 #[async_trait]
 impl AppResource for DeploymentResource {
-  fn render<B: Backend>(block: ActiveBlock, f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
+  fn render(block: ActiveBlock, f: &mut Frame<'_>, app: &mut App, area: Rect) {
     draw_resource_tab!(
       DEPLOYMENTS_TITLE,
       block,
@@ -95,7 +94,7 @@ impl AppResource for DeploymentResource {
   }
 }
 
-fn draw_block<B: Backend>(f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
+fn draw_block(f: &mut Frame<'_>, app: &mut App, area: Rect) {
   let title = get_resource_title(app, DEPLOYMENTS_TITLE, "", app.data.deployments.items.len());
 
   draw_resource_block(
