@@ -1,7 +1,6 @@
 use async_trait::async_trait;
 use k8s_openapi::{api::apps::v1::StatefulSet, chrono::Utc};
 use ratatui::{
-  backend::Backend,
   layout::{Constraint, Rect},
   widgets::{Cell, Row},
   Frame,
@@ -68,7 +67,7 @@ pub struct StatefulSetResource {}
 
 #[async_trait]
 impl AppResource for StatefulSetResource {
-  fn render<B: Backend>(block: ActiveBlock, f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
+  fn render(block: ActiveBlock, f: &mut Frame<'_>, app: &mut App, area: Rect) {
     draw_resource_tab!(
       STFS_TITLE,
       block,
@@ -89,7 +88,7 @@ impl AppResource for StatefulSetResource {
   }
 }
 
-fn draw_block<B: Backend>(f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
+fn draw_block(f: &mut Frame<'_>, app: &mut App, area: Rect) {
   let title = get_resource_title(app, STFS_TITLE, "", app.data.stateful_sets.items.len());
 
   draw_resource_block(
